interface ICAFChannelDescription {
    channelLabel: number;
    channelFlags: number;
    coordinates: readonly [number, number, number];
}
interface ICAFChannelLayout {
    channelLayoutTag: number;
    channelBitmap: number;
    numberChannelDescriptions: number;
    channelDescriptions: ICAFChannelDescription[];
}
declare class CafChanChunk {
    channelLayoutTag: number;
    channelBitmap: number;
    numberChannelDescriptions: number;
    channelDescriptions: ICAFChannelDescription[];
    readonly type = "chan";
    constructor(x: ICAFChannelLayout);
    static from: (data: Uint8Array) => CafChanChunk;
    get byteLength(): number;
    encode: () => Uint8Array;
}

declare class CafChunkStore {
    readonly type: string;
    readonly size: bigint;
    readonly sizeWithHeader: bigint;
    body: Uint8Array;
    header: Uint8Array;
    static headerSize: number;
    constructor(x: Iterable<number>);
    get byteLength(): number;
    encode: () => Uint8Array;
}

interface ICAFData {
    editCount: number;
    data: Uint8Array;
}
declare class CafDataChunk {
    readonly editCount: number;
    readonly data: Uint8Array;
    readonly type = "data";
    constructor({ editCount, data }: ICAFData);
    static from: (data: Uint8Array) => CafDataChunk;
    get byteLength(): number;
    encode: () => Uint8Array;
}

interface ICAFDescriptionChunk {
    sampleRate: number;
    formatID: string;
    formatFlags: number;
    bytesPerPacket: number;
    framesPerPacket: number;
    channelsPerFrame: number;
    bitsPerChannel: number;
}
declare class CafDescChunk {
    sampleRate: number;
    formatID: string;
    formatFlags: number;
    bytesPerPacket: number;
    framesPerPacket: number;
    channelsPerFrame: number;
    bitsPerChannel: number;
    readonly type = "desc";
    constructor(x: ICAFDescriptionChunk);
    static from: (data: Uint8Array) => CafDescChunk;
    get byteLength(): number;
    encode: () => Uint8Array;
}

interface ICAFFileHeader {
    fileType: string;
    fileVersion: number;
    fileFlags: number;
}
declare class CafHeaderChunk {
    readonly fileType: string;
    readonly fileVersion: number;
    readonly fileFlags: number;
    constructor(x: ICAFFileHeader);
    static from: (x: Uint8Array) => CafHeaderChunk;
    get byteLength(): number;
    encode: () => Uint8Array;
}

interface ICAFPacketTableHeader {
    numberPackets: bigint;
    numberValidFrames: bigint;
    primingFrames: number;
    remainderFrames: number;
}
interface ICafPaktChunk {
    header: ICAFPacketTableHeader;
    body: number[];
}
declare class CafPaktChunk {
    readonly header: ICAFPacketTableHeader;
    readonly body: number[];
    readonly type = "pakt";
    constructor({ header, body }: ICafPaktChunk);
    static packetsTable: (data: Uint8Array) => number[];
    static constructPacketsTable: (numbers: number[]) => Uint8Array;
    static parsePacketTableHeader: (x: Uint8Array) => ICAFPacketTableHeader;
    static constructParsePacketTableHeader: (packetTableHeader: ICAFPacketTableHeader) => Uint8Array;
    static from: (data: Uint8Array) => CafPaktChunk;
    get byteLength(): number;
    encode: () => Uint8Array;
}

interface ICAFChunkHeader {
    chunkType: string;
    chunkSize: bigint;
}
declare const readCafChunkHeader: (x: Uint8Array) => ICAFChunkHeader;

type CafChunk = CafChanChunk | CafDataChunk | CafDescChunk | CafPaktChunk | CafChunkStore | CafHeaderChunk;
interface ITestModeResult$1 {
    header: ICAFChunkHeader;
    raw: Uint8Array;
    chunk: CafChunk;
}
declare function fetchCafOpusFile<TestMode extends boolean>(url: string, testMode: TestMode): AsyncGenerator<TestMode extends true ? ITestModeResult$1 : CafChunk, null, unknown>;

declare class OggFormatError extends Error {
}
interface IOpusChannelMapping {
    streamCount: number;
    coupledCount: number;
    channelMapping: number[];
}
interface IOggHeader {
    version: number;
    channelCount: number;
    preSkip: number;
    inputSampleRate: number;
    outputGain: number;
    mappingFamily: number;
    channelMapping: IOpusChannelMapping | null;
}
interface IOggTags {
    vendorString: string;
    userCommentString: string[];
}
declare class OggPage {
    readonly buffer: Uint8Array;
    ready: boolean;
    structureVersion: number;
    headerType: number;
    isFreshPacket: boolean;
    isBos: boolean;
    isBoe: boolean;
    absoluteGranulePosition: bigint;
    streamSerialNumber: number;
    pageSequenceNumber: number;
    pageChecksum: number;
    pageSegments: number;
    segmentTable: Uint8Array;
    parsedSegmentTable: number[];
    dataView: DataView;
    pageSize: number;
    constructor(buffer: Uint8Array);
    validatePageSize: () => void;
    getPageSegment: (i: number) => Uint8Array;
    mapSegments: <T>(callback: (x: Uint8Array, index: number) => T) => T[];
    static validatePage(buffer: Uint8Array): {
        dataView: DataView;
        pageBodySize: number;
        pageSize: number;
        pageSegmentsCount: number;
    };
    getOggHeader(): IOggHeader;
    getOggTags(): IOggTags;
    getTimestamp(preSkip: number): bigint;
}

declare enum Mode {
    SILK = 0,
    Hybrid = 1,
    CELT = 2
}
declare enum BandWidth {
    NB = 0,
    MB = 1,
    WB = 2,
    SWB = 3,
    FB = 4
}
declare enum FrameSize {
    Ms2d5 = 2.5,
    Ms5 = 5,
    Ms10 = 10,
    Ms20 = 20,
    Ms40 = 40,
    Ms60 = 60
}
interface OpusFrameConfig {
    index: number;
    mode: Mode;
    bandWidth: BandWidth;
    frameSize: FrameSize;
}
declare enum Channel {
    Mono = 0,
    Stereo = 1
}
declare class OpusParseError extends Error {
}
interface IOpusPacket {
    config: OpusFrameConfig;
    channel: Channel;
    framesFlag: number;
    paddingLength: number;
    frameLengthByteLength: number;
    frameByteLengths: number[];
}
declare const parseOpusPacket: (x: Uint8Array) => IOpusPacket;

interface IOggParseResult<Type extends string, T> {
    type: Type;
    page: OggPage;
    data: T;
}
interface IOggHeaderParseResult extends IOggParseResult<'header', IOggHeader> {
}
interface IOggTagsParseResult extends IOggParseResult<'tags', IOggTags> {
}
interface IOggPacketsParseResult extends IOggParseResult<'packets', IOpusPacket[]> {
}
declare function fetchOggOpusFile(url: string): AsyncGenerator<IOggHeaderParseResult | IOggTagsParseResult | IOggPacketsParseResult, null, unknown>;

interface ITestModeResult {
    chunk: CafChunk;
    raw: Uint8Array;
}
declare function oggOpusToCaf<TestMode extends boolean>(x: AsyncGenerator<IOggHeaderParseResult | IOggTagsParseResult | IOggPacketsParseResult, null>, testMode: TestMode): AsyncGenerator<TestMode extends true ? ITestModeResult : CafChunk, TestMode extends true ? ITestModeResult : CafChunk, unknown>;

export { BandWidth, CafChanChunk, CafChunk, CafChunkStore, CafDataChunk, CafDescChunk, CafHeaderChunk, CafPaktChunk, Channel, FrameSize, ICAFChannelDescription, ICAFChannelLayout, ICAFChunkHeader, ICAFDescriptionChunk, ICAFFileHeader, IOggHeader, IOggHeaderParseResult, IOggPacketsParseResult, IOggParseResult, IOggTags, IOggTagsParseResult, IOpusChannelMapping, IOpusPacket, Mode, OggFormatError, OggPage, OpusParseError, fetchCafOpusFile, fetchOggOpusFile, oggOpusToCaf, parseOpusPacket, readCafChunkHeader };
//# sourceMappingURL=types.d.ts.map
